==> libopenshot-0.3.2-x86_64-2ponce.txz: usr/doc/libopenshot-0.3.2/API/search/all_7.js <==
var searchData=
[
  ['echo_0',['Echo',['../classopenshot_1_1Echo.html',1,'openshot::Echo'],['../classopenshot_1_1Echo.html#ababd42898feed0775f5234d53fe9bff1',1,'openshot::Echo::Echo()'],['../classopenshot_1_1Echo.html#a5f36e0e8204d782628bddfaabc6c7098',1,'openshot::Echo::Echo(Keyframe echo_time, Keyframe feedback, Keyframe mix)']]],
  ['echo_2ecpp_1',['Echo.cpp',['../Echo_8cpp.html',1,'']]],
  ['echo_2eh_2',['Echo.h',['../Echo_8h.html',1,'']]],
  ['echo_5fbuffer_3',['echo_buffer',['../classopenshot_1_1Echo.html#a85abda90423108e1c53ab2f2213251e2',1,'openshot::Echo']]],
  ['echo_5fbuffer_5fchannels_4',['echo_buffer_channels',['../classopenshot_1_1Echo.html#a1b240beb70394c06a38356f593c5d211',1,'openshot::Echo']]],
  ['echo_5fbuffer_5fsamples_5',['echo_buffer_samples',['../classopenshot_1_1Echo.html#acbf90e11e842c839e516bf36dc6bfcec',1,'openshot::Echo']]],
  ['echo_5ftime_6',['echo_time',['../classopenshot_1_1Echo.html#a345b532dee845aa832ed6b022cb3dc10',1,'openshot::Echo']]],
  ['echo_5fwrite_5fposition_7',['echo_write_position',['../classopenshot_1_1Echo.html#a5982a0fb061a07e284b8ff67826cef3b',1,'openshot::Echo']]],
  ['editing_20library_20c_20api_8',['OpenShot Video Editing Library C++ API',['../index.html',1,'']]],
  ['effectbase_9',['EffectBase',['../classopenshot_1_1EffectBase.html',1,'openshot']]],
  ['effectbase_2ecpp_10',['EffectBase.cpp',['../EffectBase_8cpp.html',1,'']]],
  ['effectbase_2eh_11',['EffectBase.h',['../EffectBase_8h.html',1,'']]],
  ['effectcamtrajectory_12',['EffectCamTrajectory',['../structEffectCamTrajectory.html',1,'EffectCamTrajectory'],['../structEffectCamTrajectory.html#a420f56610efa4c1852e5b723c626540b',1,'EffectCamTrajectory::EffectCamTrajectory()'],['../structEffectCamTrajectory.html#a7e55bbc3b6013764db5249aa29aedcd7',1,'EffectCamTrajectory::EffectCamTrajectory(double _x, double _y, double _a)']]],
  ['effectinfo_13',['EffectInfo',['../classopenshot_1_1EffectInfo.html',1,'openshot']]],
  ['effectinfo_2ecpp_14',['EffectInfo.cpp',['../EffectInfo_8cpp.html',1,'']]],
  ['effectinfo_2eh_15',['EffectInfo.h',['../EffectInfo_8h.html',1,'']]],
  ['effectinfostruct_16',['EffectInfoStruct',['../structopenshot_1_1EffectInfoStruct.html',1,'openshot']]],
  ['effects_17',['Effects',['../classopenshot_1_1Clip.html#a79201f906e8773d72bfbe29cba3ac290',1,'openshot::Clip::Effects()'],['../classopenshot_1_1Timeline.html#a51b516481ad46145120ce0bca31b3326',1,'openshot::Timeline::Effects()']]],
  ['effects_2eh_18',['Effects.h',['../Effects_8h.html',1,'']]],
  ['effecttransformparam_19',['EffectTransformParam',['../structEffectTransformParam.html',1,'EffectTransformParam'],['../structEffectTransformParam.html#a1815e0588d75c85dc044edb69b2a3690',1,'EffectTransformParam::EffectTransformParam()'],['../structEffectTransformParam.html#a18cfd17f4717d2bfedaee6d82f10ef9b',1,'EffectTransformParam::EffectTransformParam(double _dx, double _dy, double _da)']]],
  ['enable_20',['Enable',['../classopenshot_1_1ZmqLogger.html#a7d8b4d71a4347185aa440f09efceebb0',1,'openshot::ZmqLogger']]],
  ['enable_5fplayback_5fcaching_21',['ENABLE_PLAYBACK_CACHING',['../classopenshot_1_1Settings.html#ad76ba863ac268babc02d3ba1a17a6c74',1,'openshot::Settings']]],
  ['enable_5fseek_22',['enable_seek',['../classopenshot_1_1FFmpegReader.html#ae5eff8bed134126f0f6557a704df36ae',1,'openshot::FFmpegReader']]],
  ['enable_5fvaapi_23',['ENABLE_VAAPI',['../FFmpegReader_8cpp.html#a3e9ac6774840d29f75060233205a9601',1,'FFmpegReader.cpp']]],
  ['end_24',['End',['../classopenshot_1_1Clip.html#a9ea04a111c50ef5016dc6adadc28850f',1,'openshot::Clip::End() const override'],['../classopenshot_1_1Clip.html#a375e0e01ce70199aba95a88b458b868d',1,'openshot::Clip::End(float value) override'],['../classopenshot_1_1ClipBase.html#a11791c3f0116ddcd9c574b2817ad27a8',1,'openshot::ClipBase::End() const'],['../classopenshot_1_1ClipBase.html#a2e9045bb7cf6066436aa979a6665fd1a',1,'openshot::ClipBase::End(float value)']]],
  ['end_25',['end',['../classopenshot_1_1ClipBase.html#ae3c1cc3fbc40f2efad770fdea9f0c7f7',1,'openshot::ClipBase']]],
  ['end_5fof_5ffile_26',['end_of_file',['../structopenshot_1_1PacketStatus.html#a62ab9493475e28d475a0f07940a4ba7b',1,'openshot::PacketStatus']]],
  ['enums_2eh_27',['Enums.h',['../Enums_8h.html',1,'']]],
  ['environment_20variables_28',['Environment Variables',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-WINDOWS.html#autotoc_md87',1,'']]],
  ['errordecodingaudio_29',['ErrorDecodingAudio',['../classopenshot_1_1ErrorDecodingAudio.html',1,'openshot::ErrorDecodingAudio'],['../classopenshot_1_1ErrorDecodingAudio.html#a52c3bfc5124d340ed859d20576c8a447',1,'openshot::ErrorDecodingAudio::ErrorDecodingAudio()']]],
  ['errorencodingaudio_30',['ErrorEncodingAudio',['../classopenshot_1_1ErrorEncodingAudio.html',1,'openshot::ErrorEncodingAudio'],['../classopenshot_1_1ErrorEncodingAudio.html#a2ad03d36c4e617de2d24c512fd6eb4d7',1,'openshot::ErrorEncodingAudio::ErrorEncodingAudio()']]],
  ['errorencodingvideo_31',['ErrorEncodingVideo',['../classopenshot_1_1ErrorEncodingVideo.html',1,'openshot::ErrorEncodingVideo'],['../classopenshot_1_1ErrorEncodingVideo.html#af1bd19a239cf50d12306eec3f2d5e179',1,'openshot::ErrorEncodingVideo::ErrorEncodingVideo()']]],
  ['even_32',['Even',['../structopenshot_1_1MappedFrame.html#a483e7bedd6634fc65557b04f37a877c6',1,'openshot::MappedFrame']]],
  ['exactlycontains_33',['ExactlyContains',['../classopenshot_1_1TrackedObjectBase.html#a61723c50aff86cb711a5537bbfc6ca08',1,'openshot::TrackedObjectBase::ExactlyContains()'],['../classopenshot_1_1TrackedObjectBBox.html#a7f2ee3bf84e382b0183a008a704a4b2d',1,'openshot::TrackedObjectBBox::ExactlyContains()']]],
  ['example_20code_34',['Example Code',['../index.html#autotoc_md1',1,'']]],
  ['example_20variables_35',['Example Variables',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-WINDOWS.html#autotoc_md88',1,'']]],
  ['exceptionbase_36',['ExceptionBase',['../classopenshot_1_1ExceptionBase.html',1,'openshot::ExceptionBase'],['../classopenshot_1_1ExceptionBase.html#a99aa5244efd14f1536b193fcae6d93bd',1,'openshot::ExceptionBase::ExceptionBase()']]],
  ['exceptions_2eh_37',['Exceptions.h',['../Exceptions_8h.html',1,'']]],
  ['expander_38',['Expander',['../classopenshot_1_1Expander.html',1,'openshot::Expander'],['../classopenshot_1_1Expander.html#a019c4cd00bcf2c8dab680af3d92ebcbc',1,'openshot::Expander::Expander()'],['../classopenshot_1_1Expander.html#a59e5f013378c4844a798edb80a03911e',1,'openshot::Expander::Expander(Keyframe threshold, Keyframe ratio, Keyframe attack, Keyframe release, Keyframe makeup_gain, Keyframe bypass)']]],
  ['expander_2ecpp_39',['Expander.cpp',['../Expander_8cpp.html',1,'']]],
  ['expander_2eh_40',['Expander.h',['../Expander_8h.html',1,'']]],
  ['exponential_41',['EXPONENTIAL',['../namespaceopenshot.html#a27e58ce2e37551a32fe154f91c94f97daa4885980c4d5ab75c421cf97527a7939',1,'openshot']]],
  ['extend_42',['Extend',['../structopenshot_1_1SampleRange.html#ab9918a8927be0a5d225bcdc942616e96',1,'openshot::SampleRange']]],
  ['extractsamples_43',['ExtractSamples',['../classopenshot_1_1AudioWaveformer.html#af25ea5d9597d43650a4c6b28ff62cfa2',1,'openshot::AudioWaveformer']]]
];

==> libopenshot-0.3.3-x86_64-1ponce.txz: usr/doc/libopenshot-0.3.3/API/search/all_7.js <==
var searchData=
[
  ['echo_0',['Echo',['../classopenshot_1_1Echo.html',1,'openshot::Echo'],['../classopenshot_1_1Echo.html#ababd42898feed0775f5234d53fe9bff1',1,'openshot::Echo::Echo()'],['../classopenshot_1_1Echo.html#a5f36e0e8204d782628bddfaabc6c7098',1,'openshot::Echo::Echo(Keyframe echo_time, Keyframe feedback, Keyframe mix)']]],
  ['echo_2ecpp_1',['Echo.cpp',['../Echo_8cpp.html',1,'']]],
  ['echo_2eh_2',['Echo.h',['../Echo_8h.html',1,'']]],
  ['echo_5fbuffer_3',['echo_buffer',['../classopenshot_1_1Echo.html#a85abda90423108e1c53ab2f2213251e2',1,'openshot::Echo']]],
  ['echo_5fbuffer_5fchannels_4',['echo_buffer_channels',['../classopenshot_1_1Echo.html#a1b240beb70394c06a38356f593c5d211',1,'openshot::Echo']]],
  ['echo_5fbuffer_5fsamples_5',['echo_buffer_samples',['../classopenshot_1_1Echo.html#acbf90e11e842c839e516bf36dc6bfcec',1,'openshot::Echo']]],
  ['echo_5ftime_6',['echo_time',['../classopenshot_1_1Echo.html#a345b532dee845aa832ed6b022cb3dc10',1,'openshot::Echo']]],
  ['echo_5fwrite_5fposition_7',['echo_write_position',['../classopenshot_1_1Echo.html#a5982a0fb061a07e284b8ff67826cef3b',1,'openshot::Echo']]],
  ['editing_20library_20c_20api_8',['OpenShot Video Editing Library C++ API',['../index.html',1,'']]],
  ['effectbase_9',['EffectBase',['../classopenshot_1_1EffectBase.html',1,'openshot']]],
  ['effectbase_2ecpp_10',['EffectBase.cpp',['../EffectBase_8cpp.html',1,'']]],
  ['effectbase_2eh_11',['EffectBase.h',['../EffectBase_8h.html',1,'']]],
  ['effectcamtrajectory_12',['EffectCamTrajectory',['../structEffectCamTrajectory.html',1,'EffectCamTrajectory'],['../structEffectCamTrajectory.html#a420f56610efa4c1852e5b723c626540b',1,'EffectCamTrajectory::EffectCamTrajectory()'],['../structEffectCamTrajectory.html#a7e55bbc3b6013764db5249aa29aedcd7',1,'EffectCamTrajectory::EffectCamTrajectory(double _x, double _y, double _a)']]],
  ['effectinfo_13',['EffectInfo',['../classopenshot_1_1EffectInfo.html',1,'openshot']]],
  ['effectinfo_2ecpp_14',['EffectInfo.cpp',['../EffectInfo_8cpp.html',1,'']]],
  ['effectinfo_2eh_15',['EffectInfo.h',['../EffectInfo_8h.html',1,'']]],
  ['effectinfostruct_16',['EffectInfoStruct',['../structopenshot_1_1EffectInfoStruct.html',1,'openshot']]],
  ['effects_17',['Effects',['../classopenshot_1_1Clip.html#a79201f906e8773d72bfbe29cba3ac290',1,'openshot::Clip::Effects()'],['../classopenshot_1_1Timeline.html#a51b516481ad46145120ce0bca31b3326',1,'openshot::Timeline::Effects()']]],
  ['effects_2eh_18',['Effects.h',['../Effects_8h.html',1,'']]],
  ['effecttransformparam_19',['EffectTransformParam',['../structEffectTransformParam.html',1,'EffectTransformParam'],['../structEffectTransformParam.html#a1815e0588d75c85dc044edb69b2a3690',1,'EffectTransformParam::EffectTransformParam()'],['../structEffectTransformParam.html#a18cfd17f4717d2bfedaee6d82f10ef9b',1,'EffectTransformParam::EffectTransformParam(double _dx, double _dy, double _da)']]],
  ['enable_20',['Enable',['../classopenshot_1_1ZmqLogger.html#a7d8b4d71a4347185aa440f09efceebb0',1,'openshot::ZmqLogger']]],
  ['enable_5fplayback_5fcaching_21',['ENABLE_PLAYBACK_CACHING',['../classopenshot_1_1Settings.html#ad76ba863ac268babc02d3ba1a17a6c74',1,'openshot::Settings']]],
  ['enable_5fseek_22',['enable_seek',['../classopenshot_1_1FFmpegReader.html#ae5eff8bed134126f0f6557a704df36ae',1,'openshot::FFmpegReader']]],
  ['enable_5fvaapi_23',['ENABLE_VAAPI',['../FFmpegReader_8cpp.html#a3e9ac6774840d29f75060233205a9601',1,'FFmpegReader.cpp']]],
  ['end_24',['End',['../classopenshot_1_1Clip.html#a9ea04a111c50ef5016dc6adadc28850f',1,'openshot::Clip::End() const override'],['../classopenshot_1_1Clip.html#a375e0e01ce70199aba95a88b458b868d',1,'openshot::Clip::End(float value) override'],['../classopenshot_1_1ClipBase.html#a11791c3f0116ddcd9c574b2817ad27a8',1,'openshot::ClipBase::End() const'],['../classopenshot_1_1ClipBase.html#a2e9045bb7cf6066436aa979a6665fd1a',1,'openshot::ClipBase::End(float value)']]],
  ['end_25',['end',['../classopenshot_1_1ClipBase.html#ae3c1cc3fbc40f2efad770fdea9f0c7f7',1,'openshot::ClipBase']]],
  ['end_5fof_5ffile_26',['end_of_file',['../structopenshot_1_1PacketStatus.html#a62ab9493475e28d475a0f07940a4ba7b',1,'openshot::PacketStatus']]],
  ['enums_2eh_27',['Enums.h',['../Enums_8h.html',1,'']]],
  ['environment_20variables_28',['Environment Variables',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-WINDOWS.html#autotoc_md87',1,'']]],
  ['errordecodingaudio_29',['ErrorDecodingAudio',['../classopenshot_1_1ErrorDecodingAudio.html',1,'openshot::ErrorDecodingAudio'],['../classopenshot_1_1ErrorDecodingAudio.html#a52c3bfc5124d340ed859d20576c8a447',1,'openshot::ErrorDecodingAudio::ErrorDecodingAudio()']]],
  ['errorencodingaudio_30',['ErrorEncodingAudio',['../classopenshot_1_1ErrorEncodingAudio.html',1,'openshot::ErrorEncodingAudio'],['../classopenshot_1_1ErrorEncodingAudio.html#a2ad03d36c4e617de2d24c512fd6eb4d7',1,'openshot::ErrorEncodingAudio::ErrorEncodingAudio()']]],
  ['errorencodingvideo_31',['ErrorEncodingVideo',['../classopenshot_1_1ErrorEncodingVideo.html',1,'openshot::ErrorEncodingVideo'],['../classopenshot_1_1ErrorEncodingVideo.html#af1bd19a239cf50d12306eec3f2d5e179',1,'openshot::ErrorEncodingVideo::ErrorEncodingVideo()']]],
  ['even_32',['Even',['../structopenshot_1_1MappedFrame.html#a483e7bedd6634fc65557b04f37a877c6',1,'openshot::MappedFrame']]],
  ['exactlycontains_33',['ExactlyContains',['../classopenshot_1_1TrackedObjectBase.html#a61723c50aff86cb711a5537bbfc6ca08',1,'openshot::TrackedObjectBase::ExactlyContains()'],['../classopenshot_1_1TrackedObjectBBox.html#a7f2ee3bf84e382b0183a008a704a4b2d',1,'openshot::TrackedObjectBBox::ExactlyContains()']]],
  ['example_20code_34',['Example Code',['../index.html#autotoc_md1',1,'']]],
  ['example_20variables_35',['Example Variables',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-WINDOWS.html#autotoc_md88',1,'']]],
  ['exceptionbase_36',['ExceptionBase',['../classopenshot_1_1ExceptionBase.html',1,'openshot::ExceptionBase'],['../classopenshot_1_1ExceptionBase.html#a99aa5244efd14f1536b193fcae6d93bd',1,'openshot::ExceptionBase::ExceptionBase()']]],
  ['exceptions_2eh_37',['Exceptions.h',['../Exceptions_8h.html',1,'']]],
  ['expander_38',['Expander',['../classopenshot_1_1Expander.html',1,'openshot::Expander'],['../classopenshot_1_1Expander.html#a019c4cd00bcf2c8dab680af3d92ebcbc',1,'openshot::Expander::Expander()'],['../classopenshot_1_1Expander.html#a59e5f013378c4844a798edb80a03911e',1,'openshot::Expander::Expander(Keyframe threshold, Keyframe ratio, Keyframe attack, Keyframe release, Keyframe makeup_gain, Keyframe bypass)']]],
  ['expander_2ecpp_39',['Expander.cpp',['../Expander_8cpp.html',1,'']]],
  ['expander_2eh_40',['Expander.h',['../Expander_8h.html',1,'']]],
  ['exponential_41',['EXPONENTIAL',['../namespaceopenshot.html#a27e58ce2e37551a32fe154f91c94f97daa4885980c4d5ab75c421cf97527a7939',1,'openshot']]],
  ['extend_42',['Extend',['../structopenshot_1_1SampleRange.html#ab9918a8927be0a5d225bcdc942616e96',1,'openshot::SampleRange']]],
  ['extractsamples_43',['ExtractSamples',['../classopenshot_1_1AudioWaveformer.html#af25ea5d9597d43650a4c6b28ff62cfa2',1,'openshot::AudioWaveformer']]]
];
